.TH GEOSTAT 1
.SH NAME
geostat \- navigation routines for geostationnary satellites
.SH DOWNLOAD
http://www.icare.univ-lille1.fr/projets/ducos/geostat/geostat.tar.gz
.SH SOURCE FILES
http://www.icare.univ-lille1.fr/projets/ducos/geostat/src
.SH SYNOPSIS
.B #include "geostat.h"

.B geostat_err_t geostat_init(const char *\fIsatellite\fP)

.B geostat_err_t geostat_latlon_to_rowcol_double(double \fIlatitude\fP, double \fIlongitude\fP, double *\fIrow\fP, double *\fIcolumn\fP)

.B geostat_err_t geostat_rowcol_to_latlon_double(double \fIrow\fP, double \fIcolumn\fP, double *\fIlatitude\fP, double *\fIlongitude\fP)

.B geostat_err_t geostat_latlon_to_rowcol(const double \fIlatitude\fP, const double \fIlongitude\fP, unsigned long *\fIrow\fP, unsigned long *\fIcolumn\fP)

.B geostat_err_t geostat_rowcol_to_latlon(const unsigned long \fIrow\fP, const unsigned long \fIcolumn\fP, double *\fIlatitude\fP, double *\fIlongitude\fP)

.B geostat_err_t geostat_get_azimuth_and_zenithal(const double \fIlatitude\fP, const double \fIlongitude\fP, double *\fIazimuth\fP, double *\fIzenithal\fP)
.SH DESCRIPTION
.PP
Hopefully the function names should be self-explanatory. Inputs are passed by values,
outputs passed by pointers (only one value addressed by each pointer). The functions suffixed
by \fB_double\fP handle fractional rows and columns instead of integral values.

\fBgeostat_init\fP must be called before any other function of the package.
It must be given the name of the satellite ("meteosat", "goes_E", "msg")
for which all subsequent computations will be performed. The behavior of
other functions is undefined if \fBgeostat_init\fP has not returned the
\fBGEOSTAT_ERR_OK\fP value.

.SH RETURN VALUES
.PP
.TP
.B \fBGEOSTAT_ERR_OK\fP              ( \fI0\fP)     
success, values returned by pointer may be used safely
.TP
.B \fBGEOSTAT_ERR_OUT_OF_RANGE\fP    (\fI-1\fP)
input data (row, column) or (latitude, longitude) not corresponding to any valid output
.TP
.B \fBGEOSTAT_ERR_BAD_INIT\fP        (\fI-2\fP)     
call to \fIgeostat_init\fP failed or was forgotten
.TP
.B \fBGEOSTAT_ERR_BAD_INPUT_COORD\fP (\fI-3\fP)     
invalid input values latitude, longitude (only for functions \fBgeostat_latlon_*\fP)
.PP

NB. The distinction between GEOSTAT_ERR_OUT_OF_RANGE and GEOSTAT_ERR_BAD_INPUT_COORD seems
somewhat artificial, it comes from the underlying fortran code which returns distinct error codes
(the hardcoded values documented here) depending on the situation.

.SH COPYRIGHT
geostat is Copyright (c) Icare 2006
(original code in Fortran supplied by Genevieve Seze from LMD, geostat is a C wrapper from Icare).
.PP
This program is free software; you can redistribute it and/or modify
it under the terms of the CeCILL French Free Software License, as published by
the www.cecill.info website; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
CeCILL French Free Software License for more details.

You should have received a copy of the CeCILL License
along with this program; if not, you may find one on the
www.cecill.info website.
.SH BUGS
.PP
None we are aware of.
.PP
Please report any bug you could find to problem@icare.univ-lille1.fr
.SH AUTHORS
Fabrice Ducos
